# HAMSCLIENT fork

This was forked from https://github.com/websylv/hamsclient because
the original author was unresponsive and had nearly no activity on
Github for the last year, leading to no release and therefore no
actual fixes forthe Meteo Swiss HACS integration for Home Assistant,
broken ever since.

This is now released on PyPI as `hamsclientfork` and it powers
my fork of the Meteo Swiss at https://github.com/Rudd-O/homeassistant-meteoswiss .

